package com.mortals.xhx.module.staff.web;

import com.mortals.framework.annotation.UnAuth;
import com.mortals.framework.common.Rest;
import com.mortals.framework.model.Context;
import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.xhx.base.system.param.service.ParamService;
import com.mortals.xhx.module.staff.model.StaffPerformStatEntity;
import com.mortals.xhx.module.staff.model.vo.StaffSummaryTopQuery;
import com.mortals.xhx.module.staff.service.StaffPerformStatService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.ObjectUtils;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
/**
*
* 员工绩效统计
*
* @author zxfei
* @date 2023-05-17
*/
@RestController
@RequestMapping("staff/perform/stat")
public class StaffPerformStatController extends BaseCRUDJsonBodyMappingController<StaffPerformStatService,StaffPerformStatEntity,Long> {

    @Autowired
    private ParamService paramService;

    public StaffPerformStatController(){
        super.setModuleDesc( "员工绩效统计");
    }

    @Override
    protected void init(Map<String, Object> model, Context context) {
        this.addDict(model, "month", paramService.getParamBySecondOrganize("StaffPerformStat","month"));
        this.addDict(model, "day", paramService.getParamBySecondOrganize("StaffPerformStat","day"));
        super.init(model, context);
    }

    /**
     * 部门绩效排行榜
     * @param query
     * @return
     */
    @PostMapping({"summary/top"})
    @UnAuth
    public Rest<Object> getSummaryTopList(@RequestBody StaffSummaryTopQuery query) {
        Rest<Object> ret = new Rest();
        Map<String, Object> model = new HashMap();
        Context context = this.getContext();
        String busiDesc = "查询个人绩效排行榜";
        int code = 1;
        try {
            List<StaffPerformStatEntity> result = this.getService().getSummaryTopList(query);
            model.put("data", result);
            model.put("message_info", busiDesc + "成功");
            if (!ObjectUtils.isEmpty(context) && !ObjectUtils.isEmpty(context.getUser())) {
                this.recordSysLog(this.request, busiDesc + " 【成功】");
            }
        } catch (Exception var9) {
            code = -1;
            this.doException(this.request, busiDesc, model, var9);
        }
        this.init(model, context);
        ret.setCode(code);
        ret.setData(model.get("data"));
        ret.setMsg(model.get("message_info") == null ? "" : model.remove("message_info").toString());
        return ret;
    }

}